/* IMWheel Header File for more private functions
 * VERSION 0.9.6
 * Development release
 * Copylefted under the Linux GNU Public License
 * No code here may be used for profit without the permission of the author.
 * Author : Jonathan Atkins <jcatki@most.fw.hac.com> <jcatki@mysolution.com>
 * PLEASE: contact me if you have any improvements, I will gladly code good ones
 */
#ifndef IMWHEEL_H
#define IMWHEEL_H

char getInput(Display *d, XEvent *e, XModifierKeymap **xmk, char km[32], char *button);
void grabButtons(Display *d, Window w);
void ungrabButtons(Display *d, Window w);
void freeAllX(XClassHint *xch, XModifierKeymap **xmk, char **wname);
typedef struct
{
	char x,y;
} Stick;

extern const char *optionusage[][2];
extern Bool grabbed;
extern int buttonFlip, useFifo, detach, quit, pid_check, restart, threshhold;
extern int fifofd;
extern char *fifoName, *displayName;
extern Stick stick;

#endif
